ifndef cameraSelect_wdl;
define cameraSelect_wdl;

// ver: 2
// date: 040505


// title: Camera Selection
// image: cameraSelect.pcx
// help: Handles camera selection.


// needs: display00.wdl

// prefix: cameraSelect_
// idcode: 008


// entry: Key to rotate main view to the next valid camera
// id: 1
string cameraSelect_rot_next_c = "F7";


// Bitfield used to track the number of valid cameras
var	cameraSelect_valid_cameras = 0;

// Largest bit value for a valid camera
var cameraSelect_max_camera = 0;


// ---------------------------------------------------------------------
// Function Prototypes
function	CameraSelect_Next();	// rotate main view to the next valid camera


// Desc: Used to init the camera selection functions/vars
starter CameraSelect_Init()
{
	diag("\nWDL-Loaded:cameraSelect.wdl");
	// init camera ids for views


//--	cameraSelect_max_camera = 512;	// TEST!!!!!!!!!!!!1

	// map keys
	Key_Set(Key_For_Str(cameraSelect_rot_next_c),CameraSelect_Next);

	// done with init, finalize setup after all cameras have been added
	wait(1);	// allow camera starter functions to finish
	while(0 == CameraSelect_Next())	// pick first valid camera
	{
		wait(1);	// continue trying until a camera is found
	}

}


// Desc: 'rotate' the main veiw to the next valid camera
function	CameraSelect_Next()
{
	var	temp;

	// move to next posible camera
	if(display_active_camera_vec[0] == 0)
	{
		// save current active camera to stop endless looping
		temp = 1;

		display_active_camera_vec[0] = 1;
	}
	else
	{
		// save current active camera to stop endless looping
		temp = display_active_camera_vec[0];

		// move to next valid camera point
		display_active_camera_vec[0] = display_active_camera_vec[0] << 1;
	}

	// while we haven't found a valid camera
	//  & we havent completed a complete loop
	while(((display_active_camera_vec[0] & cameraSelect_valid_cameras) == 0)  // not a valid camera
		&& (display_active_camera_vec[0] != temp))                              // haven't looped all the way round
	{
		// if we have exceeded the maximum number of valid cameras
		if(display_active_camera_vec[0] > cameraSelect_max_camera)
		{
			// start at slot 1
			display_active_camera_vec[0] = 1;
		}
		else
		{
		 	// go to next slot
			display_active_camera_vec[0] = display_active_camera_vec[0] << 1;
		}
	}

	if((display_active_camera_vec[0] & cameraSelect_valid_cameras) == 0)
	{
		return(0);	// no valid camera found
	}
	return(1);	// valid camera found (may be same camera)

}

endif;